about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--clippy_lints/src/unused_self.rs4
-rw-r--r--tests/ui/unused_self.stderr18
2 files changed, 11 insertions, 11 deletions
diff --git a/tests/ui/unused_self.stderr b/tests/ui/unused_self.stderr
index 497adddb8bc..0534b40eabb 100644
--- a/tests/ui/unused_self.stderr
+++ b/tests/ui/unused_self.stderr
@@ -5,7 +5,7 @@ LL |         fn unused_self_move(self) {}
    |                             ^^^^
    |
    = note: `-D clippy::unused-self` implied by `-D warnings`
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:12:28
@@ -13,7 +13,7 @@ error: unused `self` argument
 LL |         fn unused_self_ref(&self) {}
    |                            ^^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:13:32
@@ -21,7 +21,7 @@ error: unused `self` argument
 LL |         fn unused_self_mut_ref(&mut self) {}
    |                                ^^^^^^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:14:32
@@ -29,7 +29,7 @@ error: unused `self` argument
 LL |         fn unused_self_pin_ref(self: Pin<&Self>) {}
    |                                ^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:15:36
@@ -37,7 +37,7 @@ error: unused `self` argument
 LL |         fn unused_self_pin_mut_ref(self: Pin<&mut Self>) {}
    |                                    ^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:16:35
@@ -45,7 +45,7 @@ error: unused `self` argument
 LL |         fn unused_self_pin_nested(self: Pin<Arc<Self>>) {}
    |                                   ^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:17:28
@@ -53,7 +53,7 @@ error: unused `self` argument
 LL |         fn unused_self_box(self: Box<Self>) {}
    |                            ^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:18:40
@@ -61,7 +61,7 @@ error: unused `self` argument
 LL |         fn unused_with_other_used_args(&self, x: u8, y: u8) -> u8 {
    |                                        ^^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: unused `self` argument
   --> $DIR/unused_self.rs:21:37
@@ -69,7 +69,7 @@ error: unused `self` argument
 LL |         fn unused_self_class_method(&self) {
    |                                     ^^^^^
    |
-   = help: consider refactoring to a static method or function
+   = help: consider refactoring to a associated function
 
 error: aborting due to 9 previous errors
diff --git a/clippy_lints/src/unused_self.rs b/clippy_lints/src/unused_self.rs
index aa37d1c2e06..06b11b6c38c 100644
--- a/clippy_lints/src/unused_self.rs
+++ b/clippy_lints/src/unused_self.rs
@@ -10,7 +10,7 @@ use crate::utils::span_help_and_lint;
 declare_clippy_lint! {
     /// **What it does:** Checks methods that contain a `self` argument but don't use it
     ///
     /// **Why is this bad?** It may be clearer to define the method as a static function instead
     /// of an instance method if it doesn't require `self`.
     ///
     /// **Known problems:** None.
@@ -68,7 +68,7 @@ impl<'a, 'tcx> LateLintPass<'a, 'tcx> for UnusedSelf {
                                 UNUSED_SELF,
                                 self_param.span,
                                 "unused `self` argument",
-                                "consider refactoring to a static method or function",
+                                "consider refactoring to a associated function",
                             )
                         }
                     }
@@ -10,7 +10,7 @@ use crate::utils::span_help_and_lint;
     /// **What it does:** Checks methods that contain a `self` argument but don't use it
     ///
-    /// **Why is this bad?** It may be clearer to define the method as a static function instead
+    /// **Why is this bad?** It may be clearer to define the method as an associated function instead
     /// of an instance method if it doesn't require `self`.
     ///